@@ -10,7 +10,7 @@ use sn_data_types::{PublicKey, SignedTransfer, Token, TransferAgreementProof};
 use sn_messaging::client::{Cmd, Event, Query, QueryResponse, TransferCmd, TransferQuery};
 use sn_transfers::{ActorEvent, TransferInitiated};
 
-use crate::{client::Client, errors::Error};
+use crate::{Client, Error};
 
 use log::{debug, info, trace};
 
